@@ -11,9 +11,15 @@ from .grammer import FileHandler, Grammer
 @click.option("--column-name", "-c", default="Keyword", type=str, show_default=True)
 @click.option("--max-n", "-m", default=5, show_default=True)
 @click.option("--top-results", "-t", default=250, show_default=True)
+@click.option("--stopwords", "-w", default=True, show_default=True)
 @click.version_option(version=__version__)
 def main(
-    file_path: str, sheet_name: str, column_name: str, max_n: int, top_results: int
+    file_path: str,
+    sheet_name: str,
+    column_name: str,
+    max_n: int,
+    top_results: int,
+    stopwords: bool,
 ) -> None:
     """Excel n-grams project CLI interface."""
     read_file = FileHandler(
@@ -26,7 +32,9 @@ def main(
 
     click.echo("Performing n-gram analysis...")
 
-    n_gram_dataframe = grammer.ngram_range(max_n, top_n_results=top_results)
+    n_gram_dataframe = grammer.ngram_range(
+        max_n, top_n_results=top_results, stopwords=stopwords
+    )
     output_file_path = grammer.output_csv_file(n_gram_dataframe)
 
     click.secho(f"CSV file written to {output_file_path}.", fg="green")
